#!/bin/bash

# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#UPGRADE_SAVE_DIR=/opt/ibm/director/vmi/upgrade/save
#SAVED_DATA_PATH=${UPGRADE_SAVE_DIR}/director
#SAVED_LOG_PATH=${UPGRADE_SAVE_DIR}/log

# Code added for HA handling (chrg command).
UPGRADE_LDAP_BACKUP_DIR=/ldap/backup.ldif
UPGRADE_LDAP_LOG=/ldap/05-upgrade-ldap-config.log
PID_FILE=/var/run/slapd/slapd.pid
source /opt/ibm/director/lwi/runtime/itme/eclipse/plugins/bin/RGFunctions.sh

echo "********Start ldap upgrade `date` ********" >$UPGRADE_LDAP_LOG

echo "Stop local LDAP server:" >>$UPGRADE_LDAP_LOG

#Exit Status for chrg command
# 0 Command has run successfully.
# 1 Error occurred with RMC. 
# 2 Error occurred with CLI script. 
# 3 Incorrect flag on command line.

/opt/ibm/director/vmi/scripts/execWithPrivilege/smhapstatus.sh  &>/dev/null
HArc=$? 
echo "HA return code getting HA status is $HArc" >>$UPGRADE_LDAP_LOG 
if [ $HArc -eq 4 ]; then
   echo "HA is not configured" >>$UPGRADE_LDAP_LOG 
   # stop the ldap server

   /etc/init.d/ldap stop >>$UPGRADE_LDAP_LOG 2>&1
   # check pid file to see if ldap server ended, if not, kill the process
   if  [ -f $PID_FILE ]; then
    echo "'$PID_FILE' file exist" >>$UPGRADE_LDAP_LOG
    echo "ldap server still running, try to kill the process:" >>$UPGRADE_LDAP_LOG 
    killall slapd >>$UPGRADE_LDAP_LOG 2>&1
  fi
else
 if [ $HArc -eq 0 ]; then
  echo "HA node is active"  >>$UPGRADE_LDAP_LOG 
  echo "chrg -o offline" >>$UPGRADE_LDAP_LOG
  chrg -o offline $RGname >>$UPGRADE_LDAP_LOG 2>&1
  wait_for_rg_offline  >>$UPGRADE_LDAP_LOG 2>&1
  RC=$?
  echo "Wait for ldap to go offline returned $RC">>$UPGRADE_LDAP_LOG
  if [ $RC -eq 0 ]; then
       echo "ldap server is offline" >>$UPGRADE_LDAP_LOG
  else
     echo "ldap server failed to go offline" >>$UPGRADE_LDAP_LOG
  fi

 fi
fi

# again check pid file to see if ldap server ended, if not, exit with error
if  [ -f $PID_FILE ]; then
 echo "Cannot stop ldap server! Exit upgrade" >>$UPGRADE_LDAP_LOG
 echo "********Failed to upgrade ldap server at `date` ********" >>$UPGRADE_LDAP_LOG
 exit 1
fi

# start to backup ldap server data 
echo "Backup /var/lib/ldap except DB_CONFIG" >>$UPGRADE_LDAP_LOG
mv /var/lib/ldap/alock /var/lib/ldap/alock.bk
mv /var/lib/ldap/__db.001 /var/lib/ldap/__db.001.bk
mv /var/lib/ldap/__db.002 /var/lib/ldap/__db.002.bk
mv /var/lib/ldap/__db.003 /var/lib/ldap/__db.003.bk
mv /var/lib/ldap/__db.004 /var/lib/ldap/__db.004.bk
mv /var/lib/ldap/__db.005 /var/lib/ldap/__db.005.bk
mv /var/lib/ldap/__db.006 /var/lib/ldap/__db.006.bk
#rm -f /var/lib/ldap/DB_CONFIG
mv /var/lib/ldap/dn2id.bdb /var/lib/ldap/dn2id.bdb.bk
mv /var/lib/ldap/entryCSN.bdb /var/lib/ldap/entryCSN.bdb.bk
mv /var/lib/ldap/entryUUID.bdb /var/lib/ldap/entryUUID.bdb.bk
mv /var/lib/ldap/id2entry.bdb /var/lib/ldap/id2entry.bdb.bk
mv /var/lib/ldap/log.0000000001 /var/lib/ldap/log.0000000001.bk
mv /var/lib/ldap/objectClass.bdb /var/lib/ldap/objectClass.bdb.bk

#start migrate
echo "slapadd migrate local LDAP config" >>$UPGRADE_LDAP_LOG
/usr/sbin/slapadd -l $UPGRADE_LDAP_BACKUP_DIR && echo "File migrated successfully" || echo "File migration failed" >>$UPGRADE_LDAP_LOG

if [ $HArc -eq  0 ]; then
 echo "chrg -o online" >>$UPGRADE_LDAP_LOG
 chrg -o online $RGname  >>$UPGRADE_LDAP_LOG 2>&1
 wait_for_rg_online   >>$UPGRADE_LDAP_LOG 2>&1
 RC=$?
 echo "Wait for ldap to go online returned $RC">>$UPGRADE_LDAP_LOG
 if [ $RC -eq 0 ]; then
     echo "ldap server is online" >>$UPGRADE_LDAP_LOG
 else
     echo "ldap server failed to go online" >>$UPGRADE_LDAP_LOG
 fi

fi

if [ $HArc -eq  4 ]; then
 #start ldap server
  echo "Start local LDAP server:" >>$UPGRADE_LDAP_LOG
  /etc/init.d/ldap start >>$UPGRADE_LDAP_LOG 2>&1
fi

#check ldap server status
echo "Local LDAP server status" >>$UPGRADE_LDAP_LOG
/etc/init.d/ldap status >>$UPGRADE_LDAP_LOG 2>&1

if  [ -f $PID_FILE ]; then
 echo "********LDAP server successfully upgraded `date` ********" >>$UPGRADE_LDAP_LOG
 echo "Remove /var/lib/ldap backup files except DB_CONFIG" >>$UPGRADE_LDAP_LOG
 rm -f /var/lib/ldap/alock.bk
 rm -f /var/lib/ldap/__db.001.bk
 rm -f /var/lib/ldap/__db.002.bk
 rm -f /var/lib/ldap/__db.003.bk
 rm -f /var/lib/ldap/__db.004.bk
 rm -f /var/lib/ldap/__db.005.bk
 rm -f /var/lib/ldap/__db.006.bk
 rm -f /var/lib/ldap/dn2id.bdb.bk
 rm -f /var/lib/ldap/entryCSN.bdb.bk
 rm -f /var/lib/ldap/entryUUID.bdb.bk
 rm -f /var/lib/ldap/id2entry.bdb.bk
 rm -f /var/lib/ldap/log.0000000001.bk
 rm -f /var/lib/ldap/objectClass.bdb.bk
else
 echo "********Failed to start LDAP server at `date` , return to previous version ********" >>$UPGRADE_LDAP_LOG
 echo "Remove /var/lib/ldap except DB_CONFIG" >>$UPGRADE_LDAP_LOG 
 rm -f /var/lib/ldap/alock
 rm -f /var/lib/ldap/__db.001
 rm -f /var/lib/ldap/__db.002
 rm -f /var/lib/ldap/__db.003
 rm -f /var/lib/ldap/__db.004
 rm -f /var/lib/ldap/__db.005
 rm -f /var/lib/ldap/__db.006
 rm -f /var/lib/ldap/dn2id.bdb
 rm -f /var/lib/ldap/entryCSN.bdb
 rm -f /var/lib/ldap/entryUUID.bdb
 rm -f /var/lib/ldap/id2entry.bdb
 rm -f /var/lib/ldap/log.0000000001
 rm -f /var/lib/ldap/objectClass.bdb
 
 echo "Restore the backed up files in /var/lib/ldap " >>$UPGRADE_LDAP_LOG
 mv /var/lib/ldap/alock.bk /var/lib/ldap/alock
 mv /var/lib/ldap/__db.001.bk /var/lib/ldap/__db.001
 mv /var/lib/ldap/__db.002.bk /var/lib/ldap/__db.002
 mv /var/lib/ldap/__db.003.bk /var/lib/ldap/__db.003
 mv /var/lib/ldap/__db.004.bk /var/lib/ldap/__db.004
 mv /var/lib/ldap/__db.005.bk /var/lib/ldap/__db.005
 mv /var/lib/ldap/__db.006.bk /var/lib/ldap/__db.006
 mv /var/lib/ldap/dn2id.bdb.bk /var/lib/ldap/dn2id.bdb
 mv /var/lib/ldap/entryCSN.bdb.bk /var/lib/ldap/entryCSN.bdb
 mv /var/lib/ldap/entryUUID.bdb.bk /var/lib/ldap/entryUUID.bdb
 mv /var/lib/ldap/id2entry.bdb.bk /var/lib/ldap/id2entry.bdb
 mv /var/lib/ldap/log.0000000001.bk /var/lib/ldap/log.0000000001
 mv /var/lib/ldap/objectClass.bdb.bk /var/lib/ldap/objectClass.bdb


#start ldap server
echo "Start local LDAP server:" >>$UPGRADE_LDAP_LOG
 
 if [ $HArc -eq  0 ]; then
  echo "chrg -o online" >>$UPGRADE_LDAP_LOG
  chrg -o online $RGname  >>$UPGRADE_LDAP_LOG 2>&1
  wait_for_rg_online >>$UPGRADE_LDAP_LOG 2>&1
  RC=$?
  echo "Wait for ldap to go online returned $RC">>$UPGRADE_LDAP_LOG
  if [ $RC -eq 0 ]; then
     echo "ldap server is online" >>$UPGRADE_LDAP_LOG
  else
     echo "ldap server failed to go online" >>$UPGRADE_LDAP_LOG
  fi
 fi

 if [ $HArc -eq  4 ]; then
  /etc/init.d/ldap start >>$UPGRADE_LDAP_LOG 2>&1
 fi

 #check ldap server status
 echo "Local LDAP server status" >>$UPGRADE_LDAP_LOG
 /etc/init.d/ldap status >>$UPGRADE_LDAP_LOG 2>&1
fi

# check if role permissions need to be added.
CAPTURE=
CAPTURE=$(sed -n '/<permission id="resetToLocal"\/>/p' /opt/ibm/director/vmi/data/conf/role_permission.xml)
echo "roles found:" ${#CAPTURE} >>$UPGRADE_LDAP_LOG
if [ ${#CAPTURE} == 0 ];
then
sed -i 's/\(\s*\)<name>smadmin<\/name>/&\n\1<permission id="resetToLocal"\/>\n\1<permission id="chlocalpwd"\/>\n\1<permission id="enablePEonFSM"\/>\n\1<permission id="enableLdapWatchdop"\/>\n\1<permission id="disableLdapWatchdog"\/>\n\1<permission id="slpcheckBackend.sh"\/>\n\1<permission id="bypassLicenseAndSetup"\/>/' /opt/ibm/director/vmi/data/conf/role_permission.xml
echo "added the permissions to the roles file " >>$UPGRADE_LDAP_LOG 
else
echo "permissions already exist - file OK " >>$UPGRADE_LDAP_LOG
fi

#=========================================================================
# Check if unsecure SNMPv1 and v2 need to be added.
#=========================================================================
FILE=/opt/ibm/director/lwi/conf/overrides/frm.properties
CAPTURE=
CAPTURE=$(grep -i 'security_policy_level' $FILE  | cut -f2 -d'=')
echo "Security mode:" $CAPTURE >> $UPGRADE_LDAP_LOG
if [ $CAPTURE == 20 ];
then
snmpv1=
snmpv1=$(sed -n '/snmp.trap.v1.enabled/p' /opt/ibm/director/data/snmp/SNMPServer.properties)
snmpv2=
snmpv2=$(sed -n '/snmp.trap.v2.enabled/p' /opt/ibm/director/data/snmp/SNMPServer.properties)
echo "snmp found:" $snmpv1 " " $snmpv2 >> $UPGRADE_LDAP_LOG
if [ "$snmpv1" == ""  ];
then
echo "snmp.trap.v1.enabled=false" >> /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Added snmpv1 false to file." >> $UPGRADE_LDAP_LOG
else
sed -i 's/snmp.trap.v1.enabled=true/snmp.trap.v1.enabled=false/' /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Changed snmpv1 value to false " >> $UPGRADE_LDAP_LOG 
fi
if [ "$snmpv2" == ""  ];
then
echo "snmp.trap.v2.enabled=false" >> /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Added snmpv2 false to file." >> $UPGRADE_LDAP_LOG
else
sed -i 's/snmp.trap.v2.enabled=true/snmp.trap.v2.enabled=false/' /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Changed snmpv2 value to false " >> $UPGRADE_LDAP_LOG 
fi
else
echo "In legacy mode - file OK " >> $UPGRADE_LDAP_LOG
sed -i 's/snmp.trap.v1.enabled=false/snmp.trap.v1.enabled=true/' /opt/ibm/director/data/snmp/SNMPServer.properties
sed -i 's/snmp.trap.v2.enabled=false/snmp.trap.v2.enabled=true/' /opt/ibm/director/data/snmp/SNMPServer.properties
fi

exit 0