#!/bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2012 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

RGname=ldapd-rg
SAVE_LDAP_LOG=/var/log/fsm_backuplog
export CT_MANAGEMENT_SCOPE=2

# The following functions added for HA handling
# This function waits for the specified resource group to come online.
# The wait period is 30 seconds.
# Function Exit status:  0  resource group is online
#                        1  resource group is not online
#                        2  cannot obtain resource group status

wait_for_rg_online () {
    local i=   
    local rc=
    local RGname=ldapd-rg

    for i in {1..6}
    do
        get_rg_status_num $RGname
        rc=$?

        case $rc in
           1 ) return 0
               ;;
          99 ) # error
               return 2
               ;;
           * ) sleep 5
               ;;
         esac
    done
    return 1
}
# This function waits for the specified resource group to go offline.
# The wait period is 30 seconds).
#
# Function Exit status:  0  resource group is offline
#                        1  resource group is not offline and not pending offline
#                        2  cannot obtain resource group status

wait_for_rg_offline ()  {
    local i=   
    local rc=
    local RGname=ldapd-rg

    for i in {1..6}
    do
        get_rg_status_num $RGname
        rc=$?

        case $rc in
           2|3 ) return 0
                 ;;
             4 ) # stuck online, just fail
                 return 1
                 ;;
            99 ) # error
                 return 2
                 ;;
             * ) sleep 5
                 ;;
         esac
    done
    return 1
}

# This function obtains the OpState value of the specified resource group.
# 
#
# Function Exit status:  0  unknown
#                        1  online
#                        2  offline
#                        3  failed offline
#                        4  stuck online
#                        5  pending online
#                        6  pending offline
#                       99  error
get_rg_status_num  (){
    
 	local RGname=ldapd-rg
	local RC

    rg_opstate=$(lsrsrc-api -s "IBM.ResourceGroup::Name == \"${RGname}\"::OpState" 2>> $SAVE_LDAP_LOG)
    RC=$?
  	echo "lsrsrc-api returned $RC" >> $SAVE_LDAP_LOG
    if [ -z "$rg_opstate" ]; then
        rg_opstate=99
    fi

    return $rg_opstate
}