
-- Table of SNMP user data with auto-generated
-- primary key ROW_ID
CREATE TABLE DB2INST1.FSMSNMPUSER_USERS
    ( ROW_ID INT NOT NULL GENERATED ALWAYS AS IDENTITY
          (START WITH 1, INCREMENT BY 1, NO CACHE),
      USER_NAME VARCHAR(64) NOT NULL,
      PASSWORD VARCHAR(512) NOT NULL,
      PASSWORD_CHANGED_TIME TIMESTAMP(0) NOT NULL WITH DEFAULT CURRENT TIMESTAMP,
      PASSWORD_EXPIRE_DAYS INTEGER NOT NULL WITH DEFAULT 60,
      CONTEXT_NAME VARCHAR(64) NOT NULL,
      AUTH_PROTO VARCHAR(16) NOT NULL WITH DEFAULT 'None',
      PRIV_PROTO VARCHAR(16) NOT NULL WITH DEFAULT 'None',
      PRIV_PROTO_PW VARCHAR(512),
      ACCESS_TYPE VARCHAR(16) NOT NULL WITH DEFAULT 'get',
      TRAP_HOSTNAME VARCHAR(128),
      CHASSIS_AUTHORITY_LEVEL INTEGER,
      BLADE_PRIVILEGES INTEGER,
      RESERVED_INT1 INTEGER,
      RESERVED_INT2 INTEGER,
      RESERVED_STR1 VARCHAR(128),
      RESERVED_STR2 VARCHAR(128),
        PRIMARY KEY (ROW_ID),
        UNIQUE (USER_NAME)
    );

-- Table of chassis UUIDs with auto-generated
-- primary key ROW_ID
CREATE TABLE DB2INST1.FSMSNMPUSER_CHASSIS
    ( ROW_ID INT NOT NULL GENERATED ALWAYS AS IDENTITY
          (START WITH 1, INCREMENT BY 1, NO CACHE),
      UUID VARCHAR(64) NOT NULL,
      SNMP_CENTRAL_ENABLED SMALLINT NOT NULL WITH DEFAULT 0,
      RESERVED_INT1 INTEGER,
      RESERVED_STR1 VARCHAR(128),
        PRIMARY KEY (ROW_ID),
        UNIQUE (UUID)
    );

-- Table of User-Chassis relationships with foreign
-- keys to entries in the Users and Chassis tables.
CREATE TABLE DB2INST1.FSMSNMPUSER_USERTOCHASSIS
    ( USER_KEY INT,
      CHASSIS_KEY INT,
        FOREIGN KEY (USER_KEY)
          REFERENCES DB2INST1.FSMSNMPUSER_USERS (ROW_ID) ON DELETE CASCADE,
        FOREIGN KEY (CHASSIS_KEY)
          REFERENCES DB2INST1.FSMSNMPUSER_CHASSIS (ROW_ID) ON DELETE CASCADE
    );

-- Add an entry of all 'F's to represent the
-- special notion of "All chassis'"
INSERT INTO DB2INST1.FSMSNMPUSER_CHASSIS
    ( UUID )
    VALUES
    ( 'FFFFFFFF-FFFF-FFFF-FFFF-FFFFFFFFFFFF' );

-- Cross-product view of all users and chassis' to
-- aid in lookup of user and chassis primary keys
-- for the relationship table
CREATE VIEW DB2INST1.FSMSNMPUSER_ALLUSERSANDCHASSISVIEW
    ( USER_ID, USER_NAME, CHASSIS_ID, UUID ) AS
        SELECT Users.ROW_ID, Users.USER_NAME,
               Chassis.ROW_ID, Chassis.UUID
        FROM DB2INST1.FSMSNMPUSER_USERS AS Users,
             DB2INST1.FSMSNMPUSER_CHASSIS AS Chassis;

-- View on the UserToChassis relationship table that
-- joins the user name and the chassis UUID to each
-- row to aid in lookup operations
CREATE VIEW DB2INST1.FSMSNMPUSER_USERTOCHASSISVIEW AS
    SELECT UC.USER_KEY, UC.CHASSIS_KEY,
           U.USER_NAME, C.UUID
    FROM (DB2INST1.FSMSNMPUSER_USERTOCHASSIS AS UC JOIN
          DB2INST1.FSMSNMPUSER_USERS AS U ON UC.USER_KEY=U.ROW_ID) JOIN
              DB2INST1.FSMSNMPUSER_CHASSIS AS C ON UC.CHASSIS_KEY=C.ROW_ID;

-- Deletion trigger on the UserToChassis view to allow
-- simplified removal of user-chassis relationships
-- based on user name and chassis UUID rather than
-- primary keys
CREATE TRIGGER DB2INST1.FSMSNMPUSER_ONDELETECHSREL
    INSTEAD OF DELETE ON DB2INST1.FSMSNMPUSER_USERTOCHASSISVIEW
    REFERENCING OLD AS UCV
    FOR EACH ROW
    DELETE FROM DB2INST1.FSMSNMPUSER_USERTOCHASSIS
        WHERE USER_KEY = UCV.USER_KEY AND
              CHASSIS_KEY = UCV.CHASSIS_KEY;

