#!/bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=backupHDD
export PATH=/usr/bin:/bin:$PATH
. /usr/bin/gettext.sh

BACKUP_COMMAND="launchBackup.sh"

# This is to handle the case where the user hits ctrl+c from the terminal
terminate_process(){
        child_pid=$(ps -ef | grep backupp | grep -v grep | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 2)
        kill -SIGINT $child_pid
}
trap 'terminate_process' SIGINT

PROPERTIES="/opt/ibm/director/lwi/conf/overrides/frm.properties"
PROPERTY_NAME="security_policy_level"
extraArgs=""

print_usage (){
	printf "`gettext 'Creates a backup of FSM image to the local HDD.'`\n"
	printf "`gettext 'Usage: backupHDD \n\nExample:\n  backupHDD '`\n"
	/opt/ibm/director/vmi/bin/execWithPrivilege auditLogger backupHDD 1
}

# print help
if [ "$1" == "-h" ] || [  "$1" == "--help" ]; then
	print_usage
	exit 0
fi 

ARGS=`getopt -ua -n $COMMAND_NAME -o "n" -- $*`
[[ $? -ne 0 ]] && rc=1

if [[ $rc -eq 1 ]];then
	/opt/ibm/director/vmi/bin/execWithPrivilege auditLogger backupHDD $rc
	exit $rc
fi

set $ARGS --

# Parse the arguments
while [ "$1" != "--" ]
do
	case "$1" in
			-n)
			extraArgs=" -n"
			;;
	esac
	shift
done

security_level=`sed '/^\#/d' $PROPERTIES | grep $PROPERTY_NAME | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`

/opt/ibm/director/vmi/bin/execWithPrivilege $BACKUP_COMMAND -d -r false -s $security_level$extraArgs

/opt/ibm/director/vmi/bin/execWithPrivilege auditLogger backupHDD $?
