#! /bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=chHttpTunnel
. /usr/bin/gettext.sh

export PATH=/usr/bin:/sbin:/usr/sbin:/bin:/usr/smrshbin/:$PATH

SCRIPT="/opt/ibm/director/proddata/itme/datamgmt/removePort.sh"
PROP_NAME="itme_portforward"
PROP_FILE="/opt/ibm/director/lwi/conf/overrides/frm.properties"

smstatus > /dev/null 2>&1
rc=$?
if [[ $rc -eq 0 ]];then
	# If Director is running we will use the Java side code, otherwise what happens is the properties file changes, but the Java code doesn't see the change
	# because the Java loads the properties into local cache, so it won't see changes made from the OS
	smcli portForwarder $@
	exit $?
elif [[ $rc -eq 1 ]];then
	# We won't change the configuration while Director is starting. We can't use the smcli command because Director is not started, and we don't know when
	# the Java code will read the properties file, so we don't want to make changes from the file system during startup, for the same reasons we won't do
	# them when Director is running
	printf "`gettext 'The IBM Flex System Manager is starting. To ensure consistency please wait for the server to finish starting before executing this command. Use smstatus -r and wait for the status to become Active.'`\n"
	exit 1
else
	# The Director server is either shutting down, is down or is in error. In any of these states it should be safe to make changes to the properties file
	# without conflicting with the Java code.
	if [[ $1 == "-D" ]];then
		# Sets hosts.allow and hosts.deny to be readable by only root, this sets permissions to -rw-r-----
		chmod 640 /etc/hosts.allow /etc/hosts.deny
		
		# Modify the switch in the properties file
		sed "s/\($PROP_NAME=\).*/\1false/" $PROP_FILE > $PROP_FILE

		# Clean up the currently open ports
		ports=$(ls -l /etc/xinetd.d/ | grep -oP '\d\d\d\d\d')
		for port in $ports
		do
			SCRIPT $port
		done
	elif [[ $1 == "-E" ]];then
		# Code requires hosts.allow and hosts.deny to be readable to more then just root, this sets permissions to -rw-r--r--
		chmod 644 /etc/hosts.allow /etc/hosts.deny

		# Modify the switch in the properties file
		sed "s/\($PROP_NAME=\).*/\1false/" $PROP_FILE > $PROP_FILE
	fi
fi
