#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2010 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

#!/bin/bash

#############################################################

OUTFILE=/opt/ibm/director/vmi/data/genesis.out
:>$OUTFILE


RUNCOMMAND_PATH=/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil 
#OVFPATH=/opt/ibm/ae/AP
OVFPATH=/etc/ovf-transport
FLAGFILE=/opt/ibm/director/vmi/data/.genesiscompleted

function compressAddress {
  local COMPRESSED=
  IFS=":"
  for i in $1; do
    COMPRESSED=$COMPRESSED$i
  done
  unset IFS    
  echo $COMPRESSED
}

echo checking ovf-env for dhcp-then-static >> $OUTFILE
if [ ! -f $OVFPATH/ovf-env.xml ]; then
  echo $OVFPATH/ovf-env.xml does not exist >> $OUTFILE
else
  LINE=$(grep '<Property ovfenv:key="cfgeth0.iptype"' $OVFPATH/ovf-env.xml)
  echo $LINE >> $OUTFILE
fi
if [ -n "$(grep '<Property ovfenv:key="cfgeth0.iptype" ovfenv:value="dhcp-then-static"/>' $OVFPATH/ovf-env.xml)" ]; then
  echo checking flagfile >> $OUTFILE
  if [ ! -f $FLAGFILE ]; then
	#
	# Get the MAC address of the FSM to use as hostname
	#
    echo getting MAC address >> $OUTFILE
	HOSTNAME_BASE="FSM-"
    MAC_ADDRESS_FULL=$(/opt/ibm/director/vmi/bin/lsnetcfg -n | grep "mac_address_eth0" | awk -F": " '{print $2}')
    MAC_ADDRESS=$(compressAddress $MAC_ADDRESS_FULL)
	if [ -n "$MAC_ADDRESS" ]; then
	  HOSTNAME="${HOSTNAME_BASE}${MAC_ADDRESS}"
	else
	  HOSTNAME="${HOSTNAME_BASE}000000000000"
	fi
	echo hostname=$HOSTNAME >> $OUTFILE
	
	#
	# Get the slot number of the FRM to use as part of the static IP address
	#
	STATIC_IP_BASE="192.168.70.2"
	SLOT_NUMBER=$($RUNCOMMAND_PATH runcommand dmidecode | grep "Location In Chassis"  | awk -F"Chassis: Slot" '{print $2}')
	if [[ -n "$SLOT_NUMBER" ]]; then
	  if [[ "$SLOT_NUMBER" == [0123456789] ]]; then
	    STATIC_IP="${STATIC_IP_BASE}0${SLOT_NUMBER}"
	  elif [[ "$SLOT_NUMBER" == [0123456789][0123456789] ]]; then
	    STATIC_IP="${STATIC_IP_BASE}${SLOT_NUMBER}"
	  else
	    STATIC_IP="${STATIC_IP_BASE}00"
	  fi
	else
	  STATIC_IP="${STATIC_IP_BASE}00"
	fi
	echo IPAddress=$STATIC_IP >> $OUTFILE
	
	#
	# Modify the ovf-env.xml file with new hostname and IP address values
	#
	sed '
	# set iptype to new value of dhcp-then-static
	s/<Property ovfenv:key="cfgeth0\.iptype" ovfenv:value=".*"\/>/<Property ovfenv:key="cfgeth0\.iptype" ovfenv:value="dhcp-then-static"\/>/
	# set static IP to 192.168.70.2xx where xx is the slot number
	s/<Property ovfenv:key="cfgeth0\.ipv4address" ovfenv:value=".*"\/>/<Property ovfenv:key="cfgeth0\.ipv4address" ovfenv:value="'$STATIC_IP'"\/>/
	# set hostname to FSM-xxxxxxxxxx where xxxxxxxxxx is the MAC address
	s/<Property ovfenv:key="cfghostgateway\.hostname" ovfenv:value=".*"\/>/<Property ovfenv:key="cfghostgateway\.hostname" ovfenv:value="'$HOSTNAME'"\/>/
	' $OVFPATH/ovf-env.xml>$OVFPATH/ovf-env-new.xml

    echo ovf-env has been modified >> $OUTFILE	
	mv $OVFPATH/ovf-env.xml $OVFPATH/ovf-env-$DATE.xml
	mv $OVFPATH/ovf-env-new.xml $OVFPATH/ovf-env.xml
	rm $OVFPATH/ovf-env-$DATE.xml
	
	touch $FLAGFILE
  fi
fi
