#!/bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

# Script run from the guest OS.
# Valid options: -f, -u, -i, -p, -P, -d, -r, -s, -n
# -d : indicates a backup to local disk
# -f : indicates a FTP backup
# -u : indicates a USB backup
# -i user_id : The user ID to gain access to the FTP server
# -p password : The password to gain access to the FTP server
# -P path : the absolute path to either the USB drive or to the FTP server
# -r [true | false] : is the backup supposed to be a reliable backup
# -s level : Security level
# -n : scheduled backup
# -I : allow interactive

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=launchBackup
. /usr/bin/gettext.sh

export PATH=/usr/bin:/sbin:/usr/sbin:/bin:/usr/smrshbin/:$PATH

#Constants #TODO These will need to change to the correct paths
#BV Need to convert this path when CSDA provides HDD backups
DISK_PATH="10.3.0.1/media/"
#"/dev/sda/"
LOG_FILE_PATH="/root/"
FSM_BACKUP_LOG="/var/log/fsm_backuplog"
ONE_TIME_PROPERTIES="/tmp/.tempBackup.properties"
BACKUP_PROPERTIES="/opt/ibm/director/lwi/conf/overrides/.backupSchedule.properties"
SCRIPT_PATH="/opt/ibm/director/proddata/itme/datamgmt/scripts/"
PROPERTY_NAME="security_policy_level"
PROPERTIES="/opt/ibm/director/lwi/conf/overrides/frm.properties"

path="$(readlink -m /dev/disk/by-path/$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand ls /dev/disk/by-path/ -lah | grep -iP 'sas.*part3' | sed -r 's/.*->(.*)/\1/g' | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'))"
CHECK_PARTITION_FORMAT="fsck -n -t ext4 $path"

#Variables
TYPE=""
USERID=""
PASSWORD=""
RELIABLE="unsafe"
FILE_PATH=""
SECURITY=0
LOG_FILE_NAME="`date +%m#%d#%Y#%H#%M#%S`"

is_scheduled=0
interactive=""

print_usage() {
	exit 2
}

exit_event() {
	local filename
	local rc=$1
	local sev
	local state
	local cond
	local msg

	if [ -e "$LOG_FILE_PATH$LOG_FILENAME" ]; then
		filename=$(awk -F'[ ,]' '/filename/ {print $8}' $LOG_FILE_PATH$LOG_FILE_NAME 2>/dev/null)
	fi

	if [ "$rc" -ne "0" ]; then
		sev=1
		state=failed
		cond=Failure
	else
		sev=4
		state=successful
		cond=Success
	fi
	
	case "$rc" in
		0) msg="The operation completed successfully.";;
		1) msg="A usage error occurred.";;
		2) msg="An internal error occurred. Creation of the snapshot failed.";;
		3) msg="The command was not performed because either authentication failed or you are not authorized to perform the action.";;
		4) msg="Failed to write to the USB device.";;
		5) msg="A usable USB device was not found.";;
		6) msg="Failed to transfer the backup file to the SFTP server.";;
		7) msg="Backup or restore is already running.";;
		8) msg="The usb option was specified, but an available USB device was not found.";;
		9) msg="Unable to communicate with the SFTP server.";;
		10) msg="Authentication with the SFTP server failed.";;
		11) msg="The specified SFTP directory path is not correct.";;
		13) msg="There was an unexpected error.";;
		14) msg="Unable to mount the USB device.";;
		16) msg="The USB device is busy.";;
		17) msg="Unable to estimate the size of the uncompressed backup.";;
		18) msg="Unable to contact hypervisor for backup.";;
		19) msg="Past the end of the scheduled backups.";;
		20) msg="There was no backup partition on the drive.";;
		21) msg="Failure to mount backup partition.";;
		22) msg="No space left on HDD for backups.";;
		23) msg="Bad parameters.";;
		50) msg="Backup parameter validation failed.";;
		51) msg="Backup notification processing failed.";; 
		52) msg="Backup preprocessing failed.";;
		53) msg="Backup postprocessing failed.";; 
		99) msg="User responded no to continuation warning.";; 
		246) msg="Backup terminated because there are background jobs running.";;
		*) msg="An internal error occurred. View log for problem details and corrective actions.";;
	esac

	/opt/ibm/director/agent/runtime/agent/subagents/director/genevent.sh \
		/compcat:"Flexible System Manager" /comptype:Backup /condtype:Result /condvalue:$cond /sev:$sev \
		/text:"Backup $state: $msg return code=$rc. Backup file ${filename:-unknown}." >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1

	exit $rc
}

compare_dates() {
	endDate=$1
	currentDate=$2
	
	endYear=`echo $endDate | cut -d'/' -f 3`
	endMonth=$((`echo $endDate | cut -d'/' -f 1`+1))
	endDay=`echo $endDate | cut -d'/' -f 2`
	endHour=`echo $endDate | cut -d'/' -f 4`
	endMinute=`echo $endDate | cut -d'/' -f 5`
	
	currentYear=`echo $currentDate | cut -d'/' -f 3`
	currentMonth=`echo $currentDate | cut -d'/' -f 1`
	currentDay=`echo $currentDate | cut -d'/' -f 2`
	currentHour=$((`echo $endDate | cut -d'/' -f 4`+1))
	currentMinute=$((`echo $endDate | cut -d'/' -f 5`+1))
	
	if [[ $currentYear -gt $endYear ]]; then
		exit 19
	elif [[ $currentMonth -gt $endMonth ]] && [[ $currentYear -eq $endYear ]]; then
		exit 19
	elif [[ $currentDay -gt $endDay ]] && [[ $currentMonth -eq $endMonth ]] && [[ $currentYear -eq $endYear ]]; then
		exit 19
	elif [[ $currentHour -gt $endHour ]] && [[ $currentDay -eq $endDay ]] && [[ $currentMonth -eq $endMonth ]] && [[ $currentYear -eq $endYear ]]; then
		exit 19
	elif [[ $currentMinute -ge $endMinute ]] && [[ $currentHour -eq $endHour ]] && [[ $currentDay -eq $endDay ]] && [[ $currentMonth -eq $endMonth ]] && [[ $currentYear -eq $endYear ]]; then
		exit 19
	fi
}

#BV This is for GA release only, this entire method should be deleted (or alter for scheduled FTP backups) in refresh
#process_scheduled_sftp_backup() {
#	if [[ ! -e /root/.ssh/authorized_keys ]]; then
#		`ssh-keygen -t rsa -N "" -f /root/.ssh/id_rsa; cp /root/.ssh/id_rsa.pub /root/.ssh/authorized_keys; cp /root/.ssh/id_rsa.pub /root/.ssh/authorized_keys2`
#	fi
#}

validate_partition(){
	doesPartitionExist=$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand fdisk -l 2>&1 | grep $path | wc -l)
    	if [[ $doesPartitionExist -eq 0 ]]; then
    		printf "`gettext 'Backup partition does not exist on the drive. This must be corrected by running a recovery of the HDD. Backup attempt terminated'`\n" 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
		/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand fdisk -l >> $FSM_BACKUP_LOG 2>&1
		printf "returncode=20\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
    		exit_event 20
    	fi
    
    	ismounted=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | wc -l`
    	ismediaused=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep /media | wc -l`
    	mountedtogether=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | grep /media | wc -l`
    
    	if [[ $ismounted -eq 0 ]];then
    		/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand $CHECK_PARTITION_FORMAT >> $FSM_BACKUP_LOG 2>&1
    		notFormatted=$?
    		if [[ $notFormatted -ne 0 ]]; then
    			printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext ' Format of backup partition required, beginning format process.'`\n" 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
    			/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mkfs -t ext4 -L Backup $path >> $FSM_BACKUP_LOG 2>&1
    			printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext ' Format of backup partition complete.'`\n" 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
	    	fi
	fi
    
	if [[ $ismounted -eq 0 && $ismediaused -eq 0 ]]; then
    		/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount $path /media >> $FSM_BACKUP_LOG 2>&1
    	elif [[ $mountedtogether -eq 0 ]]; then
    		/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand umount /media >> $FSM_BACKUP_LOG 2>&1
    		/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount $path /media >> $FSM_BACKUP_LOG 2>&1
    	fi
    
    	if [[ $(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | grep /media | wc -l) -eq 0 ]]; then
    		printf "`gettext 'Failed to mount the backup partition. Terminating backup attempt.'`\n" | tee -a $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
		printf "returncode=21\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
    		exit_event 21
    	fi
}

decrypt_password() {
	TWG_DIRECTORY_ROOT="/opt/ibm/director"
	TWG_DIRECTORY_ROOT=`cd "$TWG_DIRECTORY_ROOT" && pwd`
	TWG_DIRECTORY_BIN="$TWG_DIRECTORY_ROOT/bin"
	USMI_PLUGINS_DIR="$TWG_DIRECTORY_ROOT/lwi/runtime/USMiMain/eclipse/plugins"
	MaxVersion="0.0.0.0"
	versionArray=`ls -l $USMI_PLUGINS_DIR | grep "^d"| grep "com.ibm.director.core.kernel_"`
	for versionInArray in $versionArray
    	do
          MaxVersion=$versionInArray
    	done
	USMI_KERNEL_PLUGIN="$USMI_PLUGINS_DIR/$MaxVersion"
	DIRECTOR_PLUGINS_DIR="$TWG_DIRECTORY_ROOT/lwi/runtime/director/eclipse/plugins"
	versionArray=`ls $DIRECTOR_PLUGINS_DIR | grep "com.ibm.director.security.nl1_" | grep ".jar"| cut -d'_' -f2 | cut -d'j' -f1|sort`
	for versionInArray in $versionArray
    	do
          MaxVersion=$versionInArray
    	done
	SECURITY_NL_PLUGIN="$DIRECTOR_PLUGINS_DIR/com.ibm.director.security.nl1_""$MaxVersion""jar"
	cd "$TWG_DIRECTORY_BIN"
	"$TWG_DIRECTORY_ROOT/jre/bin/java" -cp "$TWG_DIRECTORY_ROOT/lwi/lib/passutils.jar":"$TWG_DIRECTORY_ROOT/lwi/lib/lwisecurity.jar":"$USMI_KERNEL_PLUGIN/classes/core-kernel.jar":"$SECURITY_NL_PLUGIN" com.ibm.director.security.config.PassDecrypt   $*
	echo "decrypt password returning $?" >> $FSM_BACKUP_LOG 2>&1
	return $?
}

if [ $# -lt 1 ]; then
	print_usage
fi

ARGS=`getopt -ua -n $COMMAND_NAME -o "h:d:u:f:i:p:P:r:s:n:I:S" -- $*`
[[ $? -ne 0 ]] && exit 23
set $ARGS --

# Parse the arguments
while [ "$1" != "--" ]
do
	case "$1" in
		-h|--help) print_usage;;
		-d)
			TYPE="hdd"
			FILE_PATH=$DISK_PATH
			;;
		-u)
			TYPE="usb"
			FILE_PATH=`/usr/smrshbin/lsmediadev | grep -i type=3 | tr ',' '\n' | grep mount_point | cut -d'=' -f 2- | tr '[:space:]' '#'`
			;;
		-f)
			TYPE="ftp"
			;;
		-i)
			shift
			USERID="-u $1"
			;;
		-p)
			shift
			PASSWORD="-p $1"
			;;
		-P)
			shift
			FILE_PATH=$1
			;;
		-r)
			shift
			RELIABLE=$1
			;;
		-s)
			shift
			SECURITY=$1
			;;
		-n)
			if [[ `sed '/^\#/d' $BACKUP_PROPERTIES | grep 'endDate' | wc -l` -gt 0 ]]; then
				currentDate=`date +%-m/%-d/%Y/%k/%-M`
				endDate=`sed '/^\#/d' $BACKUP_PROPERTIES | grep 'endDate' | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`
				endTime=`sed '/^\#/d' $BACKUP_PROPERTIES | grep 'firstDate'  | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//' | cut -d "/" -f4-`
				endDate=$endDate"/"$endTime
				compare_dates $endDate $currentDate
			fi
			is_scheduled=1
			;;
		-S)
			# This is used to determine the available space on the FSM's HDD
			spaceAvail=$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand2 df -h -B G /media | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 4 | grep -oP '(?i)\d{1,4}g')
			echo $spaceAvail
			exit 0;;
		-I)
			interactive="-Y"
			;;
		*) print_usage;;
	esac
	shift
done

if [ $RELIABLE == "true" ]; then
        RELIABLE="safe"
else
        RELIABLE="unsafe"
fi

if [ $SECURITY -eq -1 ]; then
        SECURITY=`sed '/^\#/d' $PROPERTIES | grep $PROPERTY_NAME | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`
fi

GLOBALRC=0

touch $ONE_TIME_PROPERTIES

LOG_FILE_NAME=$LOG_FILE_NAME'_'`echo $FILE_PATH | tr '/' '#'`'_'$TYPE'_'$RELIABLE'_'$SECURITY'.log'

echo "log=$LOG_FILE_PATH$LOG_FILE_NAME" >> $ONE_TIME_PROPERTIES

echo "type=$TYPE" >> $ONE_TIME_PROPERTIES

printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext ' Beginning backup process.'`\n" > $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
echo "`date +%m/%d/%Y%t%H:%M:%S` - Beginning backup process to $TYPE" >> $FSM_BACKUP_LOG 2>&1

# This is to handle the case where the user hits ctrl+c from the terminal
terminate_process(){
        child_pid=$(ps -ef | grep backupp | grep -v -m 1 grep | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 2)
        kill -SIGINT $child_pid

	printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext ' Backup terminated by interrupt signal.'`\n" >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1

	# make sure that the level and the error code are added to the logs
	fsm_level=$(lsconfig -v | grep '^*RM' | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+//g;s/\*rm//i')
	printf "level=$fsm_level\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
	printf "returncode=53\n" >> $LOG_FILE_PATH$LOG_FILE_NAME

	validate_partition
	[[ $? -ne 0 ]] && exit $?

	/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil copyfiletohost $LOG_FILE_PATH$LOG_FILE_NAME /media/$LOG_FILE_NAME > /dev/null 2>&1

	exit_event 53
}
trap 'terminate_process' SIGINT SIGTERM SIGHUP

if [ "$TYPE" == "usb" ]; then
	echo "`date +%m/%d/%Y%t%H:%M:%S` - " >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
	if [ -z "$FILE_NAME" ]; then
		fnameflag=""
	else
		fnameflag="-d $FILE_NAME "
	fi

	if [ "$interactive" == "-Y" ]; then
		/opt/ibm/director/vmi/bin/backup -l usb $fnameflag -Y >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
		GLOBALRC=$?
	else
		/opt/ibm/director/vmi/bin/backup -l usb $fnameflag 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
		GLOBALRC=$PIPESTATUS
	fi
elif [ "$TYPE" == "ftp" ]; then

	# For security reasons we store the SFTP password encrypted in the properties file for a scheduled backup
	# So if we are doing a scheduled backup, the SFTP password was not passed in on the command line so we 
	# have to parse it from the properties file.
	if [[ $is_scheduled -eq 1 ]];then
		enc_password=$(sed '/^\#/d' $BACKUP_PROPERTIES | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+//g' | grep 'password=' | sed 's/password=//')
		enc_password=$(eval echo $enc_password)
		PASSWD=$(decrypt_password $enc_password)
		PASSWORD="-p $PASSWD"
	fi

	FTPNAME=`echo $FILE_PATH | cut -d'/' -f 1`
	FTPPATH='/'`echo $FILE_PATH | cut -d'/' -f 2-`
	echo "`date +%m/%d/%Y%t%H:%M:%S` - Backing up to server=$FTPNAME in directory=$FTPPATH" >> $FSM_BACKUP_LOG 2>&1
	# if the path is exactly '/', then add one extra slash (to be removed by the next line)
	# and add one more (total of two extra) because the backup command also removes / when it processes
	[[ "$FTPPATH" == "/" ]] && FTPPATH="///"  
	[[ $FTPPATH == */ ]] && FTPPATH=${FTPPATH%?} #if the path ends with a '/' remove it
	echo "`date +%m/%d/%Y%t%H:%M:%S` - " >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
	if [ "$interactive" == "-Y" ]; then
		/opt/ibm/director/vmi/bin/backup -l sftp -s $FTPNAME -d $FTPPATH $USERID $PASSWORD -Y >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
		GLOBALRC=$?
	else
		/opt/ibm/director/vmi/bin/backup -l sftp -s $FTPNAME -d $FTPPATH $USERID $PASSWORD 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
		GLOBALRC=$PIPESTATUS 
	fi

elif [ "$TYPE" == "hdd" ]; then
    	#BV temp this will change when CSDA adds an HDD backup option
    	validate_partition

	# The space validation code was placed here rather then in validate_partition because validate_partition is also used before copying log files to the HDD
	# This is run before the size check because this is was calls down and generates the /tmp/.backupsize file on the hypervisor
	/opt/ibm/director/vmi/bin/backup -e  >> $FSM_BACKUP_LOG 2>&1

	# The below code assumes that the backup size is always greater then 1G in size, otherwise it will break down because we are forcing 'df' to output only in terms of G because of the -B G option (in otherwords if there is only 999M or less of space on the drive 'df -h -B G' will return 1G
	backupSize=$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand2 cat /tmp/.backupsize | sed 's/g//i')
	spaceAvail=$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand2 df -h -B G /media | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 4 | grep -oP '(?i)\d{1,4}g' | sed 's/g//i')
	if [[ $backupSize -gt $spaceAvail ]];then
		printf "`gettext 'Insufficient space on the IBM Flex System Manager to store additional backups. Please cleanup old backup images from the IBM FSM before attempting another backup.'`\n" 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
		printf "returncode=22\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
		exit_event 22
	fi
    
	FTPNAME=`echo $FILE_PATH | cut -d'/' -f 1`
	FTPPATH='/'`echo $FILE_PATH | cut -d'/' -f 2-`
	[[ $FTPPATH == */ ]] && FTPPATH=${FTPPATH%?} #if the path ends with a '/' remove it
	echo "`date +%m/%d/%Y%t%H:%M:%S` - " >> $LOG_FILE_PATH$LOG_FILE_NAME 2>&1
	/opt/ibm/director/vmi/bin/backup -l sftp -s $FTPNAME -d $FTPPATH -u "root" -p "passw0rd" $interactive 2>&1 | tee -a $LOG_FILE_PATH$LOG_FILE_NAME
	GLOBALRC=$PIPESTATUS
fi

printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext 'Backup complete'`\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
echo "`date +%m/%d/%Y%t%H:%M:%S` - Backup complete" >> $FSM_BACKUP_LOG 2>&1

rm $ONE_TIME_PROPERTIES

fsm_level=$(lsconfig -v | grep RM | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+//g;s/\*rm//i')
printf "level=$fsm_level\n" >> $LOG_FILE_PATH$LOG_FILE_NAME
printf "returncode=$GLOBALRC\n" >> $LOG_FILE_PATH$LOG_FILE_NAME

validate_partition
[[ $? -ne 0 ]] && exit $?

/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil copyfiletohost $LOG_FILE_PATH$LOG_FILE_NAME /media/$LOG_FILE_NAME > /dev/null 2>&1

exit_event $GLOBALRC
