#!/bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

# Script run from the guest OS.
# Valid options: -d, -u, -p, -n, -f
# -d file : indicates a HDD restore with the name of the backup
# -u file : indicates a USB restore with the name of the backup
# -f path : indicates a SFTP restore with the full ftp server path
# -n name : the username for the SFTP server
# -p password : the password for the SFTP server

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=launchRestore
. /usr/bin/gettext.sh

export PATH=/usr/bin:/sbin:/usr/sbin:/bin:/usr/smrshbin/:$PATH

FSM_RESTORE_LOG="/var/log/fsm_restorelog"

TYPE=""
USERID=""
PASSWORD=""
NAME=""
FILE_PATH=""

path="$(readlink -m /dev/disk/by-path/$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand ls /dev/disk/by-path/ -lah | grep -iP 'sas.*part3' | sed -r 's/.*->(.*)/\1/g' | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'))"

print_usage() {
		printf "`date +%m/%d/%Y%t%H:%M:%S` - `gettext ' Restore failed with usage error'`\n" >> $FSM_RESTORE_LOG 2>&1
        exit -2
}

# This is to handle the case where the user hits ctrl+c from the terminal
terminate_process(){
        child_pid=$(ps -ef | grep restorep | grep -v grep | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 2)
        kill -SIGINT $child_pid

	exit 53
}
trap 'terminate_process' SIGINT SIGTERM SIGHUP

ARGS=`getopt -ua -n $COMMAND_NAME -o "h:d:u:f:n:p" -- $*`
[[ $? -ne 0 ]] && exit -1
set $ARGS --

# Parse the arguments
while [ "$1" != "--" ]
do
	case "$1" in
		-h|--help) print_usage;;
		-d)
			TYPE="hdd"
			shift
			NAME=$1
			;;
		-u)
			TYPE="usb"
			shift
			NAME=$1
			;;
		-f)
			TYPE="ftp"
			shift
			FILE_PATH=$1
			;;
		-n)
			shift
			USERID=$1
			;;
		-p)
			shift
			PASSWORD=$1
			;;
		*) print_usage;;
	esac
	shift
done

GLOBALRC=0

echo "`date +%m/%d/%Y%t%H:%M:%S` - Executing restore from $TYPE" >> $FSM_RESTORE_LOG 2>&1

if [ "$TYPE" == "usb" ]; then
	restore -l usb -n $NAME -Y >> $FSM_RESTORE_LOG 2>&1
	GLOBALRC=$?
elif [ "$TYPE" == "ftp" ]; then
	FTPNAME=`echo $FILE_PATH | cut -d'/' -f 1`
	FTPPATH='/'`echo $FILE_PATH | cut -d'/' -f 2-`
	[[ $FTPPATH == */ ]] && FTPPATH=${FTPPATH%?} #if the path ends with a '/' remove it
	restore -l sftp -s $FTPNAME -n $FTPPATH -u $USERID -p $PASSWORD -Y 2>&1 | tee -a $FSM_RESTORE_LOG
	GLOBALRC=$PIPESTATUS
elif [ "$TYPE" == "hdd" ]; then
	#BV temp this will change when CSDA adds an HDD backup option
	doesPartitionExist=$(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand fdisk -l 2>&1 | grep $path | wc -l)
    if [[ $doesPartitionExist -eq 0 ]]; then
 		printf "`gettext 'Backup partition does not exist on the drive. This must be corrected by running a recovery of the HDD. Restore attempt terminated'`\n"   
    	echo "Backup partition does not exist on the drive. This must be corrected by running a recovery of the HDD. Restore attempt terminated" >> $FSM_RESTORE_LOG 2>&1
    	exit -2
    fi
	
	ismounted=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | wc -l`
    ismediaused=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep /media | wc -l`
    mountedtogether=`/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | grep /media | wc -l`
    if [[ $ismounted -eq 0 && $ismediaused -eq 0 ]]; then
    	/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount $path /media >> $FSM_RESTORE_LOG 2>&1
    elif [[ $mountedtogether -eq 0 ]]; then
    	/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand umount /media >> $FSM_RESTORE_LOG 2>&1
    	/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount $path /media >> $FSM_RESTORE_LOG 2>&1
    fi
    
    if [[ $(/opt/ibm/director/vmi/scripts/execWithPrivilege/mgmtNetUtil runcommand mount | grep $path | grep /media | wc -l) -eq 0 ]]; then
    	printf "`gettext 'Failed to mount the backup partition. Terminating restore attempt'`\n"
    	echo "`date +%m/%d/%Y%t%H:%M:%S` - Failed to mount the backup partition. Terminating restore attempt" >> $FSM_RESTORE_LOG 2>&1
    	exit -3
    fi
	FTPNAME="10.3.0.1"
	FTPPATH="/media"
	restore -l sftp -s $FTPNAME -n $FTPPATH/$NAME -u root -p passw0rd -Y 2>&1 | tee -a $FSM_RESTORE_LOG
	GLOBALRC=$PIPESTATUS
fi

exit $GLOBALRC
