#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2012 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

#! /bin/bash

ldapDir=/etc/openldap/frmCerts
cmmDir=/etc/openldap/cmmCerts
keyStore=/opt/ibm/director/data/security/keystore/ibmjsse2.jts
CFGOUT=$ldapDir/lsconfig.out
SERIAL_FILE=$ldapDir/frmcaserial
IPINPUT=$ldapDir/lsnetcfg.out
CONFIG_FILE=$ldapDir/openssl.cnf
ipCount=0
# default to sha1, it will change to sha256 if in NIST mode
HASH_ALGORITHM=sha1

mkdir $cmmDir
mkdir -p $ldapDir/tmp

#new serial and index files for creating certificates
/opt/ibm/director/vmi/bin/lsconfig -v > $CFGOUT 2>&1
cat $CFGOUT | grep UUID | cut -d " " -f2- | cut -b 1-8 > $SERIAL_FILE 
touch $ldapDir/frmcaindex.txt
mkdir $ldapDir/mirror2 

#gather address info for the config file
/opt/ibm/director/vmi/bin/lsnetcfg -n > $IPINPUT 2>&1
#Get eth0 / eth1 addresses
ipv4_eth0=$(cat $IPINPUT | grep ipv4addr_eth0 | cut -d ":" -f2 | cut -d " " -f2)
ipv4_eth0=$(echo $ipv4_eth0 | sed -e  's/,/ /g')
ipv6_eth0=$(cat $IPINPUT | grep ipv6addr_eth0 | cut -d ":" -f2- | cut -d " " -f2)
ipv6_eth0=$(echo $ipv6_eth0 | sed -e  's/,/ /g' -e 's/\/[0-9]*//g')
ipv4_eth1=$(cat $IPINPUT | grep ipv4addr_eth1 | cut -d ":" -f2 | cut -d " " -f2)
ipv4_eth1=$(echo $ipv4_eth1| sed -e  's/,/ /g')
ipv6_eth1=$(cat $IPINPUT | grep ipv6addr_eth1 | cut -d ":" -f2- | cut -d " " -f2)
ipv6_eth1=$(echo $ipv6_eth1 | sed -e  's/,/ /g' -e 's/\/[0-9]*//g')

# get the current FSM_CRYPTO_MODE level, if level = nist then
# change the HASH_ALGORITHM to sha256 to comply with the NIST standard
FILE=/opt/ibm/director/lwi/conf/overrides/frm.properties
CAPTURE=$(grep -i 'fsm_crypto_mode' $FILE  | cut -f2 -d'=')
if [ "$CAPTURE" == "nist" ];
then
   # If the crypto mode property equals NIST then update HASH_ALGORITHM
   HASH_ALGORITHM=sha256	
fi

#new config file to add Subject Alternative Name and predate to cert
ipArr=("$ipv4_eth0" "$ipv6_eth0" "$ipv4_eth1" "$ipv6_eth1")
echo "[ca]" > $CONFIG_FILE 
echo "default_ca=frmca" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "[frmca]" >> $CONFIG_FILE
echo "dir           = $ldapDir" >> $CONFIG_FILE
echo "certificate   = $ldapDir/FRMServerCert.pem" >> $CONFIG_FILE
echo "database      = $ldapDir/frmcaindex.txt" >> $CONFIG_FILE
echo "new_certs_dir = $ldapDir/mirror2" >> $CONFIG_FILE
echo "private_key   = $ldapDir/newkey.pem" >> $CONFIG_FILE
echo "serial        = $ldapDir/frmcaserial" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "default_md      = "$HASH_ALGORITHM >> $CONFIG_FILE
echo "unique_subject  = no" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "policy          = frmca_policy" >> $CONFIG_FILE
echo "x509_extensions = certificate_extensions" >> $CONFIG_FILE
echo "copy_extensions  = copy" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "[ frmca_policy ]" >> $CONFIG_FILE
echo "commonName             = supplied" >> $CONFIG_FILE
echo "organizationName       = supplied" >> $CONFIG_FILE
echo "countryName            = supplied" >> $CONFIG_FILE
echo "stateOrProvinceName    = supplied" >> $CONFIG_FILE
echo "localityName           = supplied" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "[ certificate_extensions ]" >> $CONFIG_FILE
echo "basicConstraints   = CA:false" >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "[ req ]" >> $CONFIG_FILE
echo "distinguished_name = req_distinguished_name" >> $CONFIG_FILE
echo "req_extensions = v3_req" >> $CONFIG_FILE
echo "default_startdate  = 500101000000Z" >> $CONFIG_FILE
echo "default_days       = 6575" >> $CONFIG_FILE
echo "x509_extensions    = certificate_extensions" >> $CONFIG_FILE
echo "default_md         = "$HASH_ALGORITHM >> $CONFIG_FILE
echo "" >> $CONFIG_FILE
echo "[ req_distinguished_name ]" >> $CONFIG_FILE
echo "[ v3_req ]" >> $CONFIG_FILE
echo "subjectAltName = @alt_names" >> $CONFIG_FILE
echo "[ alt_names ]" >> $CONFIG_FILE

for item in ${ipArr[*]}
do
    len=$(expr length "$item")
    if [ $len -gt 2 -a $item != "0.0.0.0" -a $item != "127.0.0.1" ]; then
    	ipCount=$[$ipCount+1]
		echo "IP."$ipCount" = "$item"" >> $CONFIG_FILE
    else
    	echo "#IP:"$item" is not a valid IP" >> $CONFIG_FILE
    fi    
done

#Create CSR with Subject Alternative Name
openssl req -nodes -subj "$1" -out $ldapDir/FRMServerCert.csr -newkey rsa:2048 -keyout $ldapDir/tmp/newkey.pem -config $CONFIG_FILE

chmod 600 $ldapDir/tmp/newkey.pem

#Self sign certificate with Subject Alternative Name from CSR
openssl ca -config $ldapDir/openssl.cnf -in $ldapDir/FRMServerCert.csr -out $ldapDir/FRMServerCert.pem -keyfile $ldapDir/tmp/newkey.pem -startdate 500101000100Z -enddate 481231235959Z -batch -notext -selfsign

#Create der file for Configuration Profiles to give to CMMs
openssl x509 -outform der -in $ldapDir/FRMServerCert.pem -out $ldapDir/FRMServerCert.der

#cleanup temp config files used by openssl command
rm $CONFIG_FILE $IPINPUT $CFGOUT
rm $ldapDir/frmcaindex.*
rm /$SERIAL_FILE*
rm -r $ldapDir/mirror2 

cp $ldapDir/tmp/newkey.pem $ldapDir/tmp/newkey.pem.com

openssl rsa -in $ldapDir/tmp/newkey.pem.com -out $ldapDir/tmp/newkey.pem

cp $ldapDir/tmp/newkey.pem $ldapDir/FRMServerKey.pem
chmod 600 $ldapDir/FRMServerKey.pem

rm -r $ldapDir/tmp

# add this cert to the Director TrustStore
/opt/IBMJava/bin/keytool -import -noprompt -keystore $keyStore -storepass $2 -file $ldapDir/FRMServerCert.pem -alias frmCaCert
