#! /bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=lsTunnelPorts
. /usr/bin/gettext.sh

export PATH=/usr/bin:/usr/sbin:/bin:$PATH

CONFIG_FILE_DIR="/etc/xinetd.d/"

if [[ $# -gt 0 && ("$1" == "-h" || "$1" == "--help") ]];then
	printf "`gettext 'Usage: lsTunnelPorts\n\nUsed to list the ports that are currently opened for Endpoint Tunneling connections.'`\n"
	exit 0
fi

# This is called by the Java code to get a list of open ports. We are doing it here because Java compile fails if you use \d for the grep
# however, grep fails if you use \\d to make Java happy.
if [[ $# -gt 0 && "$1" == "-z" ]];then
	ls -l $CONFIG_FILE_DIR | grep -oP '\d\d\d\d\d'
	exit 0
fi

ports=$(ls -l $CONFIG_FILE_DIR | grep -oP '\d\d\d\d\d')
if [[ $(ls -l $CONFIG_FILE_DIR | grep -ocP '\d\d\d\d\d') -eq 0 ]];then
	printf "`gettext 'No Tunneling Ports Open'`\n"
fi
for port in $ports
do
	system_info=$(grep redirect $CONFIG_FILE_DIR$port | cut -d'=' -f 2)

	# Parse the client information from the iptables data, because we limit which clients can connect, we can generate that list from iptables
	client_info=$(iptables -L | grep $port | sed 's/^[[:space:]]*//;s/[[:space:]]*$//;s/[[:space:]]\+/,/g' | cut -d',' -f 4)
	clients=""

	printf "`gettext 'Port Number: %s\n Endpoint Tunneling To: %s\n Clients Configured for Port:\n\t '`" "$port" "$system_info"
	# Compose a string of clients that can be output to the screen, but don't display duplicates
	for client in $client_info
	do
		if [[ $(echo $clients | grep -c $client) -eq 0 ]];then
			clients="$clients $client"
			printf "$client\n\t "
		fi
	done
	printf "\n\n"
done
