#!/bin/bash

#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2010 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

# Return Code
#0: Start was successful
#1: Start failed with error
#2: LWI is already running; start failed

LWI_BIN_DIR=/opt/ibm/director/lwi/bin
STANDBY_BIN_DIR=/opt/ibm/director/standby/bin
LWI_START_OPTION="profile.standby=uimin,uistandard,rest,standby com.ibm.lwi.profile=profile.standby"
PLATFORM_XML_FILE=/opt/ibm/director/lwi/conf/org.eclipse.update/platform.xml
PLATFORM_XML_BACKUP_FILE=/opt/ibm/director/lwi/conf/org.eclipse.update/.platform.xml.backup


# Checking LWI status
STATUS=`${LWI_BIN_DIR}/lwistatus.sh`
if [ ${STATUS} == "ACTIVE" ] ; then
	echo "LWI must be stopped!"
	exit 2
fi
if [ ! -f $PLATFORM_XML_BACKUP_FILE ]; then
	cp $PLATFORM_XML_FILE $PLATFORM_XML_BACKUP_FILE
fi
# Starting LWI
RETVAL=0
echo  "Starting Standby LWI..."
nohup ${LWI_BIN_DIR}/lwistart.sh ${LWI_START_OPTION} >/dev/null 2>&1 &
STANDBY_LWI_PID=`ps -efww|grep "${LWI_START_OPTION}"|grep -v grep|awk {'print $2'}`
RETVAL=$?
if [ $RETVAL -eq 0 ]; then
	STATUS=`${LWI_BIN_DIR}/lwistatus.sh`
	COUNT=0
	while [ "$STATUS" != "ACTIVE" ]; do
		sleep 5
		COUNT=`expr $COUNT + 1`
		STATUS=`${LWI_BIN_DIR}/lwistatus.sh`
		if [ $COUNT -ge 80 ]; then
			echo "LWI is taking too long to start."
			echo "Standby LWI did not start successfully."
			exit 1
		fi
	done
	echo "Standby LWI is started."
else
	echo "Error occurred during starting standby"
	exit 1
fi

exit 0
