#!/bin/bash
# Licensed Materials - Property of IBM
# 
# 09N6996
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)
#### Use a special path for TSA monitoring scripts
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

EXPLOITER_COMMON_CODE=/opt/ibm/director/ha/bin/include/smha_exploiter_common.sh

if [ -f $EXPLOITER_COMMON_CODE ]; then
    source $EXPLOITER_COMMON_CODE
else
    echo "$PROGNAME:Exploiter common code not found."
    exit 1
fi
#############################################################

RC=0

Action=${1}

ResourceName="flexcat"

# A start and stop command must exit with 0 on success and not 0 on failure. The monitor
# command must exit with a value that indicates the status of the underlying appliance
# resource. The possible values are defined by smha_exploiter_common.sh and begin with the
# TSA_ prefix. Only these values may be used. The most common values used are
#
#   TSA_UNKNOWN=0           Status cannot be determined or there is an error
#   TSA_ONLINE=1            The resource is online, i.e. active
#   TSA_OFFLINE=2           The resource is offline, i.e. inactive
#   TSA_PENDING_ONLINE=5    The resource is starting, but not yet active
#   TSA_PENDING_OFFLINE=6   The resource is stopping, but not yet inactive
#
# In TSA terminology, each of these status values is called an OpState (Operational State).
#
# Please refer to the additional documentation in the samplecontrolledD-rg.sh or
# samplecontrolledE-rg.sh sample scripts.

# Note the calls to the smha_record_tsa_action function. Each call logs an entry
# in the HA log file. There are HA tools that examine entries for debugging.
# An actual script must also have these calls, in the place and manner shown
# below. The first two arguments to the function are always the Action and
# ResourceName. In the case of start/stop case entries, the third argument is "-". 
# In all cases the final call is passed the exit code as the third argument. Note
# that status only logs one entry.

case ${Action} in
start)
    smha_record_tsa_action $Action ${ResourceName} "-"

    service xcatd start &> /dev/null
    smha_debug_tsa "${ResourceName} program started"
    ;;
stop)
    smha_record_tsa_action $Action ${ResourceName} "-"

    service xcatd stop &> /dev/null    
    smha_debug_tsa "${ResourceName} program stopped"
    ;;

status)
    service xcatd status &> /dev/null
    status=$?
    if [ $status -eq 0 ]; then
        RC=${TSA_ONLINE}
    elif [ $status -eq 3 ]; then
        RC=${TSA_OFFLINE}
    elif [ $status -eq 150 ]; then
        RC=${TSA_PENDING_ONLINE}
    else
        RC=${TSA_UNKNOWN}
    fi
    ;;
esac
#debug_tsa "$PROGNAME $Action: rc=$RC"
smha_record_tsa_action $Action $ResourceName $RC
exit $RC
