#!/bin/bash
# Licensed Materials - Property of IBM
#
# 09N6996
#
# (C) Copyright IBM Corp. 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)
#### Use a special path for TSA monitoring scripts
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

EXPLOITER_COMMON_CODE=/opt/ibm/director/ha/bin/include/smha_exploiter_common.sh

BACKUP_BIN="/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/bin/"
PROP_FILE="/opt/ibm/director/lwi/conf/overrides/.backup.properties"
CRON_CONTROLLER="implementCron.sh"
BACKUP_SCRIPT="launchBackup.sh"

SMHA_DEBUG_TSA=ON      # enable debug

if [ -f $EXPLOITER_COMMON_CODE ]; then
    source $EXPLOITER_COMMON_CODE
else
    echo "$PROGNAME:Exploiter common code not found."
    exit 1
fi
#############################################################

# For an event type of SMHA_EVENT_MIRRORED_STORAGE, the event state is either "up" or "down"

EventType=$1
EventState=$2

smha_debug_tsa "Caught event type $EventType"

if [ "$EventType" = "$SMHA_EVENT_MIRRORED_STORAGE" ]; then

    case ${EventState} in

    up)
        # The mirrored storage resource is up on this node
        # execute logic that is dependent on mirrored storage being available
    	if [[ -e $PROP_FILE ]]; then
    		cronString=`sed '/^\#/d' $PROP_FILE | grep 'cronString'  | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`
    		if [[ `crontab -l | grep -c $BACKUP_BIN$BACKUP_SCRIPT` -eq 0 ]]; then
    			$BACKUP_BIN$CRON_CONTROLLER -a "$cronString"
    		fi
    		smha_debug_tsa "fsm backup scheduler started"
    	else
    		smha_debug_tsa "fsm no backups scheduled"
    	fi

    	;;
    down)
        # The mirrored storage resource is down on this node
        # execute logic that is dependent on mirrored storage being unavailable
    
    	$BACKUP_BIN$CRON_CONTROLLER -r $BACKUP_BIN$BACKUP_SCRIPT
    	smha_debug_tsa "fsm backup scheduler stopped"

    	;;

    esac
fi

exit 0      # always exit with 0
