#!/bin/bash
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# This script should be put in /opt/ibm/director/ha/plugins/tsa/m.6/

#include common exploiter code
source /opt/ibm/director/ha/bin/include/smha_exploiter_common.sh

TSA_PLUGIN_DIR=/opt/ibm/director/ha/plugins/tsa
RESOURCE_NAME=backup
RESOURCE_GROUP_NAME=backup-rg
RESOURCE_START_COMMAND="${TSA_PLUGIN_DIR}/fsmbackupschedulermonitor.sh start"
RESOURCE_STOP_COMMAND="${TSA_PLUGIN_DIR}/fsmbackupschedulermonitor.sh stop"
RESOURCE_MONITOR_COMMAND="${TSA_PLUGIN_DIR}/fsmbackupschedulermonitor.sh status"
MONITOR_PERIOD=10
MONITOR_TIMEOUT=30
START_TIMEOUT=120
STOP_TIMEOUT=120
USER=root
ACTIVE_NODE=$(smha_get_local_rsct_node_name)
PASSIVE_NODE=$(smha_get_remote_rsct_node_name)

create_backup_resource() {
    
    lsrg -A d -g $RESOURCE_GROUP_NAME &>/dev/null
    if [ $? -eq 6 ]; then
        smha_debug "Create the fsmbackupschedulerHAcfg resource"
        smha_debug "RESOURCE_NAME=$RESOURCE_NAME"
        smha_debug "RESOURCE_START_COMMAND=$RESOURCE_START_COMMAND"
        smha_debug "RESOURCE_STOP_COMMAND=$RESOURCE_STOP_COMMAND"
        smha_debug "RESOURCE_MONITOR_COMMAND=$RESOURCE_MONITOR_COMMAND"
        smha_debug "MONITOR_PERIOD=$MONITOR_PERIOD"
        smha_debug "MONITOR_TIMEOUT=$MONITOR_TIMEOUT"
        smha_debug "ACTIVE_NODE=$ACTIVE_NODE"
        smha_debug "PASSIVE_NODE=$PASSIVE_NODE"
        smha_debug "START_TIMEOUT=$START_TIMEOUT"
        smha_debug "STOP_TIMEOUT=$STOP_TIMEOUT"
        smha_debug "USER=$USER"
        
        mkrsrc IBM.Application \
        Name="$RESOURCE_NAME" \
        StartCommand="$RESOURCE_START_COMMAND" \
        StopCommand="$RESOURCE_STOP_COMMAND" \
        MonitorCommand="$RESOURCE_MONITOR_COMMAND" \
        MonitorCommandPeriod=$MONITOR_PERIOD \
        MonitorCommandTimeout=$MONITOR_TIMEOUT \
        NodeNameList="{'$ACTIVE_NODE','$PASSIVE_NODE'}" \
        StartCommandTimeout=$START_TIMEOUT \
        StopCommandTimeout=$STOP_TIMEOUT \
        UserName="$USER" \
        ResourceType=1
        
        mkrg -p $SMHA_ADVANCED_MGR_RG_PRIORITY $RESOURCE_GROUP_NAME
        smha_add_to_rg $RESOURCE_NAME IBM.Application $RESOURCE_GROUP_NAME O
        
        smha_make_relationship DependsOn IBM.Application:$RESOURCE_NAME \
            IBM.Application:$SMHA_DRBDM_MIRROR0_RSRC_NAME \
            $RESOURCE_NAME-depon-$SMHA_DRBDM_MIRROR0_RSRC_NAME
            
        chrg -o online $RESOURCE_GROUP_NAME
        
    else
        smha_debug "Oops.  Resource group: $RESOURCE_GROUP_NAME does not exist." 
        return -1
    fi
}

remove_backup_resource() {
    smha_remove_resource_group $RESOURCE_GROUP_NAME
}


action=$1

case ${action} in

  create)
    smha_debug "fsmbackupschedulerHAcfg.sh create called"
    # This gets called during HA configuration 
    
    create_backup_resource
  ;;

  delete)
    smha_debug "fsmbackupschedulerHAcfg.sh delete called"
    # This gets called when HA is unconfigured
    
    remove_backup_resource
  ;;
  
esac

