#!/bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# This script is used by High Avaliability for 
# invocation as part of HA configuration or termination.
# The script is called to start, end or return status for 
# scheduled backups on FSM.
# This script should be put in /opt/ibm/director/ha/plugins/tsa/


PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)
#### Use a special path for TSA monitoring scripts
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

EXPLOITER_COMMON_CODE=/opt/ibm/director/ha/bin/include/smha_exploiter_common.sh
BACKUP_BIN="/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/bin/"
PROP_FILE="/opt/ibm/director/lwi/conf/overrides/.backup.properties"
CRON_CONTROLLER="implementCron.sh"
BACKUP_SCRIPT="launchBackup.sh"

if [ -f $EXPLOITER_COMMON_CODE ]; then
    source $EXPLOITER_COMMON_CODE
else
    echo "$PROGNAME:Exploiter common code not found."
    exit 1
fi
#############################################################

RC=$TSA_UNKNOWN

Action=${1}

case ${Action} in
start)
    smha_record_tsa_action $Action Backup "-"
    #normally, you would call your startup process here
    #e.g. /etc/init.d/mydaemon start
    if [[ -e $PROP_FILE ]]; then
    	smha_debug_tsa "fsm backup scheduler started"
    	cronString=`sed '/^\#/d' $PROP_FILE | grep 'cronString'  | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`
    	if [[ `crontab -l | grep -c $BACKUP_BIN$BACKUP_SCRIPT` -eq 0 ]]; then
    		$BACKUP_BIN$CRON_CONTROLLER -a "$cronString"
    	fi
    else
    	smha_debug_tsa "fsm no backups scheduled"
    fi

    ;;

stop)
    smha_record_tsa_action $Action LDAP "-"
    #normally, you would call your stop process here
    #e.g. /etc/init.d/mydaemon stop
    # you may want to perform some sanity checking here to make sure
    # the process really died.  Especially in the case if the process
    # contains files in shared storage which needs to be unmounted
    # in the case of a manual failover.
    
    smha_debug_tsa "fsm backup scheduler stopped"
    $BACKUP_BIN$CRON_CONTROLLER -r $BACKUP_BIN$BACKUP_SCRIPT

    ;;

status)    
    #normally, you would call your status process here
    #e.g. /etc/init.d/mydaemon status
    #statusrc=$?

    if [ `crontab -l | grep -c $BACKUP_BIN$BACKUP_SCRIPT` -eq 0 ]; then
        RC=${TSA_OFFLINE}
    else
        RC=${TSA_ONLINE}
    fi
    echo $RC
    ;;
esac
#debug_tsa "$PROGNAME $Action: rc=$RC"
smha_record_tsa_action $Action Backup $RC
exit $RC